/* {{{ Copyright etc. */

/*  avwcpgeom.c - Copy certain parts of an AVW header

    Stephen Smith, FMRIB Image Analysis Group  */

/* }}} */
/* {{{ defines, includes and typedefs */

#include "libss.h"
#include "libavw.h"

void usage(void);

/* }}} */
/* {{{ usage */

void usage(void)
{
  fprintf(stderr,"Usage: avwcpgeom <source> <destination>\n");
  exit(1);
}

/* }}} */
/* {{{ main */

int main(argc,argv) 
     int argc;
     char **argv;
{
  char thestring[10000];
  struct dsr hdr, hdr2;
  FILE *fp;
  int doswap=0, i;

  if (argc<3)
    usage();
    
  /* {{{ read source */

if((fp=fopen(argv[1],"r"))==NULL)
{
  sprintf(thestring,"%s.hdr",argv[1]);
  if((fp=fopen(thestring,"r"))==NULL)
    {
      printf("Can't find image related to %s\n", argv[1]);
      exit(1);
    }
}

fread(&hdr,1,sizeof(struct dsr),fp);
fclose(fp);

if(hdr.dime.dim[0] < 0 || hdr.dime.dim[0] > 15)
     swap_hdr(&hdr);

/* }}} */
  /* {{{ read destination */

sprintf(thestring,"%s",argv[2]);

if((fp=fopen(thestring,"r"))==NULL)
{
  sprintf(thestring,"%s.hdr",argv[2]);
  if((fp=fopen(thestring,"r"))==NULL)
    {
      printf("Can't find image related to %s\n", argv[2]);
      exit(1);
    }
}

fread(&hdr2,1,sizeof(struct dsr),fp);
fclose(fp);

if(hdr2.dime.dim[0] < 0 || hdr2.dime.dim[0] > 15)
    {
      swap_hdr(&hdr2);
      doswap=1;
    }

/* }}} */
  /* {{{ copy geom */
	
memcpy(hdr2.dime.vox_units,hdr.dime.vox_units,4);
	
for(i=0;i<8;i++)
     hdr2.dime.pixdim[i]=hdr.dime.pixdim[i];

hdr2.hist.orient=hdr.hist.orient;

memcpy(hdr2.hist.originator,hdr.hist.originator,10);

/* }}} */
  /* {{{ write destination */

if ( doswap ) 
     swap_hdr(&hdr2);

if((fp=fopen(thestring,"w"))==NULL)
{
  printf("Can't write %s\n", thestring);
  exit(1);
}

fwrite(&hdr2,1,sizeof(struct dsr),fp);
fclose(fp);

/* }}} */

  exit(0);
}

/* }}} */
