/*  paradigm.cc

    Mark Woolrich, FMRIB Image Analysis Group

    Copyright (C) 1999-2000 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    WWW:      http://www.fmrib.ox.ac.uk/fsl
    Email:    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.
    
    This program is distributed in the hope that it will be useful, but in
    order that the University as a charitable foundation protects its
    assets for the benefit of its educational and research purposes, the
    University makes clear that no condition is made or to be implied, nor
    is any warranty given or to be implied, as to the accuracy of FSL, or
    that it will be suitable for any particular purpose or for use under
    any specific conditions.  Furthermore, the University disclaims all
    responsibility for the use which is made of FSL.  See the GNU General
    Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA */

#include "paradigm.h"
#include "Log.h"
#include "sigproc.h"
#include "miscmaths.h"

using namespace UTILS;

namespace UTILS {

  void Paradigm::load(const string& p_paradfname, const string& p_contrastfname, bool p_blockdesign, int p_sizets)
    {
      if(p_paradfname != "")
	SIGPROC::In(p_paradfname, designMatrix);

      if(p_contrastfname != "")
	 SIGPROC::In(p_contrastfname, contrasts);       
       
      // Check time series match up with design
      if(p_paradfname != "" && designMatrix.Nrows() != p_sizets)
	{
	  cerr << "Num scans = "<< p_sizets << ", design matrix rows = " << designMatrix.Nrows() << endl;
	  throw Exception("size of design matrix does not match number of scans\n");
	}
      
      // Check contrast matches design matrix
      if(p_paradfname != "" &&  p_contrastfname != "" && designMatrix.Ncols() != contrasts.Ncols())
	 { 
	  cerr << "Num contrast cols  = " << contrasts.Ncols() << ", design matrix cols = " 
	    << designMatrix.Ncols() << endl;
	  throw Exception("size of design matrix does not match contrast\n");
	 }

      if(p_blockdesign)
	{
	  // Need to adjust amplitude from (-1,1) to (0,1)
	  designMatrix = (designMatrix + 1)/2;
	}
    }

}







