#

#   anim - produce animation output via hand-held scripting
#
#   Stephen Smith, FMRIB Image Analysis Group
#
#   Copyright (C) 1999-2000 University of Oxford
#
#   Part of FSL - FMRIB's Software Library
#   WWW:      http://www.fmrib.ox.ac.uk/fsl
#   Email:    fsl@fmrib.ox.ac.uk
#   
#   Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
#   Imaging of the Brain), Department of Clinical Neurology, Oxford
#   University, Oxford, UK
#   
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or (at
#   your option) any later version.
#   
#   This program is distributed in the hope that it will be useful, but in
#   order that the University as a charitable foundation protects its
#   assets for the benefit of its educational and research purposes, the
#   University makes clear that no condition is made or to be implied, nor
#   is any warranty given or to be implied, as to the accuracy of FSL, or
#   that it will be suitable for any particular purpose or for use under
#   any specific conditions.  Furthermore, the University disclaims all
#   responsibility for the use which is made of FSL.  See the GNU General
#   Public License for more details.
#   
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#   USA

if { [ info exists env(FSLDIR) ] } {
    set FSLDIR $env(FSLDIR)
} else {
    set FSLDIR $PXHOME/fsl
}

source ${FSLDIR}/tcl/medxstart.tcl
set auto_path [ linsert $auto_path 0 [ file dirname [ info script ] ] ]

set filename /tmp/${USER}_rotate.tcl
set channel [open $filename "w"]

puts $channel {#
if { [ info exists env(FSLDIR) ] } {
    set FSLDIR $env(FSLDIR)
} else {
    set FSLDIR $PXHOME/fsl
}

source ${FSLDIR}/tcl/medxstart.tcl
set result [ catch { mkdir ${HOME}/ROTATEOUTPUT } ErrMsg ]
MxGetCurrentImage P0
MxGetCurrentFolder F0
MxInterpolationMode NN

# Copy in all of the logged rendering calls immediately after
# this comment, then scroll down to the next comment


# Now cut the final line above (beginning "MxVolumeRender or
# MxSurfaceRender") and paste after the relevant comment below, and
# then add, at the end of the pasted line, not forgetting a space
# first, the word PICCY, e.g.
# MxVolumeRender $P0 MI BasicVR ViewVR VolumeLightVR ShadeVR VolumeMatVR MiscVR PICCY

# Then amend the following three lines according to the values above in the
# "keylset ViewVR Rx/y/z" lines
set RX0 100
set RY0 -30
set RZ0 40

keylset ViewVR Rx $RX0
keylset ViewVR Ry $RY0
keylset BasicVR Preview false
set i 0

# if you like you can change the 10 in the following line to a
# different number of degrees to increment each rotation
for { set RZ $RZ0 } { $RZ < [ expr $RZ0 + 359.9 ] } { set RZ [ expr $RZ + 10 ] } {
    keylset ViewVR Rz $RZ
    # put MxVolume/SurfaceRender line immediately after this comment

    MxSetCurrentPage $PICCY
    set pad [format %04d $i]
    print_gif ${HOME}/ROTATEOUTPUT/rotate$pad
    lappend giflist ${HOME}/ROTATEOUTPUT/rotate$pad.gif
    incr i 1
}

set errrr [ catch { exec sh -c " ${FSLDIR}/bin/gifmerge -0 -l0 -0,0,0 ${giflist} > ${HOME}/anim_${PROCID}.gif " } junk ]

MxSetCurrentPage $P0

# OR, if you want to save a time-series of slices, delete everything
# from below the first set of comments in this file and use something
# like the following (you'll need to do the tiff-gif-anim conversion
# yourself)
#for { set i 12 } { $i < 91 } { incr i 1 } {
#    set pad [format %04d $i]
#    MxSetPrinterSetup "{Name ${HOME}/ROTATEOUTPUT/rotate$pad.tif}"
#    MxGetPageByName $F0 "Duplicate of high res transparent rendering/Slice${i}" PICCY
#    MxPrintPage $PICCY
#}
}
close $channel

exec sh $PXHOME/bin/editconv.sh $filename $filename &
MxPause "*Make sure the Folder window only takes up about half of your screen size\n* Use \"Surface/Volume Render\" to get the optimal view, and turn off the preview with the \"Preview Rendering\" button\n* Press \"File->ImageScript Logging\"\n* Turn on \"Log to Window\"\n* Press \"Clear Log Window\"\n* Create the rendered preview by pressing the \"Preview Rendering\" button\n* Use the mouse to copy and paste all of the logged calls into the editor at the point marked \"Copy in...\"\nEdit the file in the editor, obeying all comment lines starting with a \"\#\". Then save the file, EXIT THE EDITOR and press OK."

source $filename
