#

#   what_type - find out the current page type
#
#   Stephen Smith, FMRIB Image Analysis Group
#
#   Copyright (C) 1999-2000 University of Oxford
#
#   Part of FSL - FMRIB's Software Library
#   WWW:      http://www.fmrib.ox.ac.uk/fsl
#   Email:    fsl@fmrib.ox.ac.uk
#   
#   Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
#   Imaging of the Brain), Department of Clinical Neurology, Oxford
#   University, Oxford, UK
#   
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or (at
#   your option) any later version.
#   
#   This program is distributed in the hope that it will be useful, but in
#   order that the University as a charitable foundation protects its
#   assets for the benefit of its educational and research purposes, the
#   University makes clear that no condition is made or to be implied, nor
#   is any warranty given or to be implied, as to the accuracy of FSL, or
#   that it will be suitable for any particular purpose or for use under
#   any specific conditions.  Furthermore, the University disclaims all
#   responsibility for the use which is made of FSL.  See the GNU General
#   Public License for more details.
#   
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#   USA

# returns:
# 0 = no folder
# 1 = no page (possibly not possible)
# 2 = 2D image page
# 3 = 3D volume page
# 4 = 4D group page

proc what_type { popups } {

    set error [ MxGetCurrentFolder Folder ]
    if { $error == 1 } {
	puts "You don't have an open folder!"
	if { $popups } {
	    MxPause "You don't have an open folder!"
	}
	return 0

    } else {
	set error [ MxGetCurrentPage Page ]
	if { $error != 0 } {
	    puts "You don't have an open page!"
	    if { $popups } {
		MxPause "You don't have an open page!"
	    }
	    return 1

	} else {
	    MxGetPageProperties $Page Props
	    set PageType [ keylget Props Type ]
	    if { [ string match $PageType Group ] == 1 } {
		return 4

	    } else {
		if { [ string match $PageType Volume ] == 1 } {
		    return 3

		} else {
		    if { [ string match $PageType Image ] == 1 } {
			return 2

		    } else {
			puts "You don't have an open page!"
			if { $popups } {
			    MxPause "You don't have an open page!"
			}
			return 1

		    }
		}
	    }
	}
    }

}

