/*  generalio.h

    Mark Jenkinson, FMRIB Image Analysis Group

    Copyright (C) 1999-2000 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    WWW:      http://www.fmrib.ox.ac.uk/fsl
    Email:    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.
    
    This program is distributed in the hope that it will be useful, but in
    order that the University as a charitable foundation protects its
    assets for the benefit of its educational and research purposes, the
    University makes clear that no condition is made or to be implied, nor
    is any warranty given or to be implied, as to the accuracy of FSL, or
    that it will be suitable for any particular purpose or for use under
    any specific conditions.  Furthermore, the University disclaims all
    responsibility for the use which is made of FSL.  See the GNU General
    Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA */

// General IO functions (images and transformation files)


#if !defined(__generalio_h)
#define __generalio_h

#include <string>
#include "mjimage.h"
#include "newmatio.h"

#ifndef NO_NAMESPACE
 using namespace NEWMAT;
 using namespace MJIMAGE;

 namespace GENERALIO {
#endif


int make_basename(string& filename);

int read_volume(volume& target, const string& filename, short& dtype,
		bool read_img_data=true);
int read_volume(volume& target, const string& filename);
int read_volume_hdr_only(volume& target, const string& filename);

int save_volume(const volume& source, const string& filename, 
                const short dtype);
int save_volume(const volume& source, const string& filename);

int read_series(tvolume& time_series, const string& filename, short& dtype);
int read_series(tvolume& time_series, const string& filename);

int save_series(const tvolume& time_series, const string& filename, 
		const short dtype);
int save_series(const tvolume& time_series, const string& filename);


int read_matrix(Matrix &target, const string& filename, const volume& invol,
		const volume& finalvol);

int read_matrix(Matrix &target, const string& filename, const volume& invol);

int read_ascii_matrix(Matrix &target, const string& filename);

int write_ascii_matrix(const Matrix& affmat, const string& filename);

int get_outputusermat(const string& filename, Matrix& oumat);

int write_medx_matrix(const Matrix& worldmat, const string& filename, 
		      const volume& initvol, 
		      const volume& finalvol, 
		      const string& mtype, const string& reffname);


#ifndef NO_NAMESPACE
 }
#endif

#endif

